# libpythonpro
Módulo para exemplificar construção de projetos Python

Suportada Versão 3 de python

[![Build Status](https://travis-ci.com/arturlauth/libpythonpro.svg?branch=master)](https://travis-ci.com/arturlauth/libpythonpro)
travis ci ( olhar arquivo travis.yml)

[![Updates](https://pyup.io/repos/github/arturlauth/libpythonpro/shield.svg)](https://pyup.io/repos/github/arturlauth/libpythonpro/)
pyup
[![Python 3](https://pyup.io/repos/github/arturlauth/libpythonpro/python-3-shield.svg)](https://pyup.io/repos/github/arturlauth/libpythonpro/)
pyup python3

Para instalar:
``
python3 -m venv .venv
source .venv/bin/activate
pip install -r requirements
``

topicos a serem abordados:
1. Git
2. Virtual Env
3. Pip
4. teste .idearemoved2